pub struct MatrixType<'a, V: Num, const RC: usize, const C: usize> { /* private fields */ }Expand description
A structure that supports the Debug and Display traits, borrowing
a matrix; this permits a relatively simple format of a matrix
through using the [new] constructor of the type
Example
use geo_nd::matrix::{identity2, MatrixType};
assert_eq!( format!("{}", MatrixType::<f32,4,2>::new(&identity2())), "[1,0 0,1]" );Implementations