FArray

Struct FArray 

pub struct FArray<F: Float, const D: usize> { /* private fields */ }
The FArray is a wrapper around a D sized array of Floats.

It provides implementations of the traits required for a Vector trait, hence it can be used for a Vector of any size D.

Default must be provided separately as it is only implemented for [F;D] up to D=32