QArray

Struct QArray 

pub struct QArray<F>
where F: Float,
{ /* private fields */ }
The QArray is a wrapper around a D sized array of Floats.

It provides implementations of the traits required for a Vector trait, hence it can be used for a Vector of any size D.